package de.intevation.flys.artifacts.model.sq;

import de.intevation.flys.artifacts.model.Parameters;

import java.io.Serializable;

import java.util.List;

public class SQFractionResult implements Serializable {

    protected Parameters parameters;
    protected SQ[]       measurements;
    protected List<SQ[]> outliers;

    public SQFractionResult() {
    }

    public SQFractionResult(
        Parameters parameters,
        SQ[]       measurements,
        List<SQ[]> outliers
    ) {
        this.parameters   = parameters;
        this.measurements = measurements;
        this.outliers     = outliers;
    }

    public boolean isValid() {
        return parameters   != null
            && measurements != null 
            && outliers     != null;
    }

    public Parameters getParameters() {
        return parameters;
    }

    public void setParameters(Parameters parameters) {
        this.parameters = parameters;
    }


    public SQ[] getMeasurements() {
        return measurements;
    }

    public void setMeasurements(SQ[] measurements) {
        this.measurements = measurements;
    }


    public List<SQ[]> getOutliers() {
        return outliers;
    }

    public void setOutliers(List<SQ[]> outliers) {
        this.outliers = outliers;
    }


    public int getOutliersCount() {
        return outliers.size();
    }


    public SQ[] getOutliers(int idx) {
        if (idx < outliers.size()) {
            return outliers.get(idx);
        }

        return null;
    }

    public void addOutliers(SQ[] outliers) {
        this.outliers.add(outliers);
    }


    public double getMinQ() {
        double min = Double.MAX_VALUE;

        for (SQ sq: measurements) {
            double q = sq.getQ();

            if (q < min) {
                min = q;
            }
        }

        return min;
    }


    public double getMaxQ() {
        double max = -Double.MAX_VALUE;

        for (SQ sq: measurements) {
            double q = sq.getQ();

            if (q > max) {
                max = q;
            }
        }

        return max;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
